# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 0.1.0 - 2024-11-11

- Initial release

## 0.1.1 - 2024-12-12

### Changed

- Module directory from mrs to pymrs to post on PyPI

### Fixed

- Short timeout in AsyncMRSClient (#21).  

